@@ -1,4 +1,5 @@
 # print("Starting")
+import datetime
 import functools
 import io
 import json
@@ -8,6 +9,7 @@ import random
 import string
 
 import bleach
+import flask
 from flask import Blueprint, render_template, request, abort, Response, url_for, send_from_directory
 import markdown
 import PIL.Image as pil_image
@@ -91,8 +93,10 @@ def editor(path):
 
         post = dataclasses.Page(
             **data,
+            date_modified=datetime.datetime.utcnow(),
             path=path
         )
+        print(post.date_modified)
 
         result = config.db_connection.save_page(post)
         print(result)
@@ -103,7 +107,7 @@ def editor(path):
 
     page = config.db_connection.get_page(path)
 
-    return render_template("cms/main.html", nav=nav, current_page=page, url=path, images=images)
+    return render_template("cms/editor.html", nav=nav, current_page=page, url=path, images=images)
 
 
 @cms.route("admin/images", methods=["POST"])
@@ -187,36 +191,56 @@ def list_images():
 @cms.route("<path:path>")
 @require_authentication
 def page(path):
+    use_json = False
+    if request.headers.get("Accept") == "Application/JSON":
+        use_json = True
+    elif path.endswith('.json'):
+        use_json = True
+        path = path.split('.')[0]
     page = config.db_connection.get_page(path)
 
     if page is None:
         abort(404)
 
-    page.html = bleach.clean(markdown.markdown(
-        page.content,
-        extensions=['fenced_code', 'codehilite', 'tables']
-    ),
-        tags=bleach.ALLOWED_TAGS + [
-            'img',
-            'a',
-            'h1',
-            'h2',
-            'h3',
-            'h4',
-            'h5',
-            'p',
-            'br',
-            'pre',
-            'div',
-            'span'
-        ],
-        attributes={
-            **bleach.ALLOWED_ATTRIBUTES,
-            'img': ['src', 'alt'],
-            'div': ['class'],
-            'span': ['class']
-        }
-    )
+    if not use_json or request.headers.get('X-IncludeHTML', 'true').lower() != 'false':
+        page.html = bleach.clean(markdown.markdown(
+            page.content,
+            extensions=['fenced_code', 'codehilite', 'tables']
+        ),
+            tags=bleach.ALLOWED_TAGS + [
+                'img',
+                'a',
+                'h1',
+                'h2',
+                'h3',
+                'h4',
+                'h5',
+                'p',
+                'br',
+                'pre',
+                'div',
+                'span'
+            ],
+            attributes={
+                **bleach.ALLOWED_ATTRIBUTES,
+                'img': ['src', 'alt'],
+                'div': ['class'],
+                'span': ['class']
+            }
+        )
+    if use_json and request.headers.get('X-IncludeMarkdown', 'true').lower() == 'false':
+        page.content = ""
+
+    if use_json:
+        return flask.Response(
+            json.dumps({
+                "page": json.loads(page.json()),
+                "nav": [json.loads(i.json()) for i in nav]
+            }),
+            headers={
+                "Content-Type": "Application/JSON"
+            }
+        )
 
     return render_template(
         config.template_name,
