@@ -14,8 +14,8 @@ class SQLDatabaseProvider(DatabaseProvider):
 
         self.db = db
 
-        class Post(db.Model):
-            __tablename__ = "cms_post"
+        class Page(db.Model):
+            __tablename__ = "cms_page"
             id = db.Column(db.Integer, primary_key=True)
             path = db.Column(db.String(), index=True, unique=True)
             title = db.Column(db.String())
@@ -23,8 +23,9 @@ class SQLDatabaseProvider(DatabaseProvider):
             sort_order = db.Column(db.Integer)
             hidden = db.Column(db.Boolean)
             content = db.Column(db.UnicodeText)
+            date_modified = db.Column(db.DateTime)
 
-        self.Post = Post
+        self.Page = Page
 
         class Image(db.Model):
             __tablename__ = "cms_image"
@@ -39,7 +40,7 @@ class SQLDatabaseProvider(DatabaseProvider):
         db.create_all()
 
     def get_page(self, path) -> typing.Optional[dataclasses.Page]:
-        row = self.Post.query.filter_by(
+        row = self.Page.query.filter_by(
             path=path
         ).first()
         if not row:
@@ -49,50 +50,54 @@ class SQLDatabaseProvider(DatabaseProvider):
             title=row.title,
             nav_title=row.nav_title,
             sort_order=row.sort_order,
-            content=row.content
+            content=row.content,
+            date_modified=row.date_modified
         )
 
     def get_all_pages(self) -> typing.Iterable[dataclasses.StrippedPage]:
         for row in self.db.session.execute(self.db.select(
-                self.Post.title,
-                self.Post.path,
-                self.Post.nav_title,
-                self.Post.sort_order
+                self.Page.title,
+                self.Page.path,
+                self.Page.nav_title,
+                self.Page.sort_order,
+                self.Page.date_modified
         ).order_by(
-            self.Post.path
+            self.Page.path
         )):
             yield dataclasses.StrippedPage(
                 title=row.title,
                 path=row.path,
                 nav_title=row.nav_title,
-                sort_order=row.sort_order
-
+                sort_order=row.sort_order,
+                date_modified=row.date_modified
             )
 
     def save_page(self, post: dataclasses.Page):
         result = self.db.session.execute(
             self.db.update(
-                self.Post
+                self.Page
             ).where(
-                self.Post.path == post.path
+                self.Page.path == post.path
             ).values(
                 path=post.path,
                 title=post.title,
                 nav_title=post.nav_title,
                 sort_order=post.sort_order,
-                content=post.content
+                content=post.content,
+                date_modified=post.date_modified
             )
         )
         if not result.rowcount:
             self.db.session.execute(
                 self.db.insert(
-                    self.Post
+                    self.Page
                 ).values(
                     path=post.path,
                     title=post.title,
                     nav_title=post.nav_title,
                     sort_order=post.sort_order,
-                    content=post.content
+                    content=post.content,
+                    date_modified=post.date_modified
                 )
             )
 
@@ -101,7 +106,7 @@ class SQLDatabaseProvider(DatabaseProvider):
     def delete_page(self, path):
         self.db.session.execute(
             self.db.delete().where(
-                self.Post.path == path
+                self.Page.path == path
             )
         )
 
