@@ -1,4 +1,5 @@
 import pydantic
+import datetime
 
 
 class StrippedPage(pydantic.BaseModel):
@@ -6,6 +7,7 @@ class StrippedPage(pydantic.BaseModel):
     title: str
     nav_title: str
     sort_order: int
+    date_modified: datetime.datetime
     subpages: list = []
 
 
